using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using Android.App;
using Android.Content;
using Android.OS;
using Android.Runtime;
using Android.Views;
using Android.Widget;
using Xamarin.Forms;
using System.IO;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Graphics;
using Syncfusion.SfChart.XForms;
using Syncfusion.SfChart.XForms.Droid;
using Java.IO;

[assembly: Dependency(typeof(SimpleSample.Droid.ChartDependencyService))]
namespace SimpleSample.Droid
{
    public class ChartDependencyService : IChartDependencyService
    {
        public void SaveAsPDF(string filename, MemoryStream stream, SfChart formChart)
        {
            var nativechart =
                (Com.Syncfusion.Charts.SfChart)SfChartRenderer.GetNativeObject(typeof(SfChart), formChart);
            nativechart.DrawingCacheEnabled = true;
            nativechart.SaveEnabled = true;
            using (var bitmap = nativechart.DrawingCache)
            {
                var imagePath =
                    new Java.IO.File(Android.OS.Environment.ExternalStorageDirectory + "/Pictures/" + filename);
                imagePath.CreateNewFile();
                using (Stream fileStream = new FileStream(imagePath.AbsolutePath, FileMode.OpenOrCreate))
                {
                    try
                    {
                        bitmap.Compress(Android.Graphics.Bitmap.CompressFormat.Jpeg, 100, fileStream);

                        //Create a new PDF document.
                        var document = new PdfDocument();
                        var page = document.Pages.Add();
                        var graphics = page.Graphics;

                        //   graphics.DrawString("Lorem Ipsum is simply dummy text of the", font, brush, new RectangleF(0,0, page.GetClientSize().Width,200));
                        graphics.DrawImage(PdfImage.FromStream(fileStream), 0, 20, page.GetClientSize().Width,
                            page.GetClientSize().Height);
                        document.Save(stream);
                        document.Close(true);
                        SavePDF("GettingStarted.pdf", stream);
                    }
                    finally
                    {
                        fileStream.Flush();
                        fileStream.Close();
                        nativechart.DrawingCacheEnabled = false;
                    }
                }
            }
        }

        private void SavePDF(string fileName, MemoryStream stream)
        {
            var root = Android.OS.Environment.IsExternalStorageEmulated
                ? Android.OS.Environment.ExternalStorageDirectory.ToString()
                : System.Environment.GetFolderPath(System.Environment.SpecialFolder.MyDocuments);

            var myDir = new Java.IO.File(root + "/Chart");
            myDir.Mkdir();

            var file = new Java.IO.File(myDir, fileName);

            if (file.Exists()) file.Delete();

            try
            {
                var outs = new FileOutputStream(file);
                outs.Write(stream.ToArray());

                outs.Flush();
                outs.Close();
            }
            catch (Exception)
            {

            }
            if (!file.Exists()) return;
            var path = Android.Net.Uri.FromFile(file);
            var extension = Android.Webkit.MimeTypeMap.GetFileExtensionFromUrl(Android.Net.Uri.FromFile(file).ToString());
            var mimeType = Android.Webkit.MimeTypeMap.Singleton.GetMimeTypeFromExtension(extension);
            var intent = new Intent(Intent.ActionView);
            intent.SetDataAndType(path, mimeType);
            Forms.Context.StartActivity(Intent.CreateChooser(intent, "Choose App"));
        }

        public Stream GetImageStream(SfChart formsChart)
        {
            return null;
        }

        public void ViewPDF(MemoryStream stream, string filename)
        {
        }
    }
}