using System;
using System.IO;
using ChartGettingStarted;
using Foundation;
using QuickLook;
using SimpleSample;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Graphics;
using Syncfusion.SfChart.iOS;
using Syncfusion.SfChart.XForms;
using Syncfusion.SfChart.XForms.iOS.Renderers;
using UIKit;
using Xamarin.Forms;

[assembly: Dependency(typeof(ChartGettingStarted.iOS.ChartDependencyService))]
namespace ChartGettingStarted.iOS
{
    public class ChartDependencyService : IChartDependencyService
    {
		public Stream GetImageStream(SfChart formChart)
		{

			var renderer = SfChartRenderer.Convert(formChart, (VisualElement)null);
			SfChartRenderer native = renderer as SfChartRenderer;

			if (native != null && native.Control != null)
			{
				native.Control.BackgroundColor = UIColor.White;
				native.Control.Frame = new CoreGraphics.CGRect(0, 0, formChart.WidthRequest, formChart.HeightRequest);

				UIGraphics.BeginImageContextWithOptions(native.Control.Bounds.Size, opaque: true, scale: 0);
				UIImage image;

				try
				{
					native.Control.DrawViewHierarchy(native.Control.Bounds, afterScreenUpdates: true);
					image = UIGraphics.GetImageFromCurrentImageContext();
				}
				finally
				{
					UIGraphics.EndImageContext();

				}

				if(image != null)
					return image.AsJPEG().AsStream();
			}

			return null;
          
        }

		public void ViewPDF(MemoryStream stream, string filename)
		{
			var path = Environment.GetFolderPath(Environment.SpecialFolder.Personal);
			var filePath = Path.Combine(path, filename);
			try
			{

				var fileStream = File.Open(filePath, FileMode.Create);
				stream.Position = 0;
				stream.CopyTo(fileStream);
				fileStream.Flush();
				fileStream.Close();
			}
			catch (Exception e)
			{

			}

			var currentController = UIApplication.SharedApplication.KeyWindow.RootViewController;
			while (currentController.PresentedViewController != null)
				currentController = currentController.PresentedViewController;
			var currentView = currentController.View;

			var qlPreview = new QLPreviewController();
			QLPreviewItem item = new QLPreviewItemBundle(filename, filePath);
			qlPreview.DataSource = new PreviewControllerDS(item);

			currentController.PresentViewController(qlPreview, true, null);
		}

    }

    public class QLPreviewItemBundle : QLPreviewItem
    {
        string _fileName, _filePath;
        public QLPreviewItemBundle(string fileName, string filePath)
        {
            _fileName = fileName;
            _filePath = filePath;
        }

        public override string ItemTitle
        {
            get
            {
                return _fileName;
            }
        }
        public override NSUrl ItemUrl
        {
            get
            {
                var documents = NSBundle.MainBundle.BundlePath;
                var lib = Path.Combine(documents, _filePath);
                var url = NSUrl.FromFilename(lib);
                return url;
            }
        }
    }

    public class PreviewControllerDS : QLPreviewControllerDataSource
    {
        private QLPreviewItem _item;

        public PreviewControllerDS(QLPreviewItem item)
        {
            _item = item;
        }

        public override nint PreviewItemCount(QLPreviewController controller)
        {
            return 1;
        }

        public override IQLPreviewItem GetPreviewItem(QLPreviewController controller, nint index)
        {
            return _item;
        }
    }
}